// cuplode.pov
//
// (C) 2012 Sander de Jong
//
// render: 
//   povray +Icuplode.pov +W854 +H480 +A +KC +KFF150
// convert to mp4: 
//   ffmpeg -f image2 -i cuplode%03d.png -vcodec libx264 -vpre slow -vpre baseline -b 1500k cuplode.mp4
// convert to webm:
//   ffmpeg -f image2 -i cuplode%03d.png -vcodec libvpx -f webm -b 1500k cuplode.webm
// play:
//   mplayer cuplode.mp4 -loop 0

#include "colors.inc"
#include "textures.inc"

//
// Animation
//

#declare numsections = 7;
#declare section = floor( clock * numsections );

#declare ct_l  = clock * numsections - section;
#declare ct_lr = 1.0 - ct_l;
#declare ct_s  = sin(ct_l * 0.5 * pi);
#declare ct_sr = 1.0 - sin(ct_l * 0.5 * pi + 0.5 * pi);
#declare ct_q  = ct_l * ct_l;
#declare ct_qr = 1.0 - (1.0 - ct_l) * (1.0 - ct_l); 


//
// Camera and lightsources
//

camera 
{
	right x*16/10
	look_at <0, -.75, 0>	 
	
	#local cur_t = section/numsections + ct_l/numsections;
	#local cur_y = 2;
	#local cur_r = 15;
	#local cur_z = cur_r * cos(2*pi*cur_t);
	#local cur_x = cur_r * sin(2*pi*cur_t);
	 
//	location <-10, 2+1.5*sin(2*pi*cur_t), -15>
	location <-10, pi, -15>
}

light_source
{
	<-5, 30, -20>
	color White
}

light_source
{
	<20, 25, -15>
	color <0.4, 0.4, 0.4>
}


//
// Background color and fog
//

background 
{
	color Black
}

fog 
{
	distance 50
	color rgb <0.5, 0.5, 0.75>
}


//
// The scene
//

plane 
{
    y, -6
    pigment {checker Green, White}
}


#declare MetalBox = 
	box
	{
		<-0.5, -0.5, -0.5>, <0.5, 0.5, 0.5>
		pigment { color Yellow }
		finish { Metal }
	}
	
#declare cubesep = 1.0;
#declare cuberot = 0;
#declare totaloffs = 0;
#declare totalrot = 0;

#if (section = 0)
	#declare totaloffs = -2.5 + 2.5 * ct_qr;
#end
#if (section = 1)
	#declare totalrot = (360 + 270) * ct_q;
#end
#if (section = 2)
	#declare cubesep = 1.0 + ct_qr * 0.5;
	#declare totalrot = 270 + 90 * ct_qr;
#end
#if (section = 3)
	#declare cubesep = 1.5;
	#declare cuberot = 90 * ct_q;
#end
#if (section = 4)
	#declare cubesep = 1.5;
	#declare cuberot = 90 + 90 * ct_q;
#end
#if (section = 5)
	#declare cubesep = 1.5 - ct_qr * 0.5;
	#declare cuberot = 180;
#end
#if (section = 6)
	#declare totaloffs = -2.5 * ct_qr;
#end
	
union
{
	#declare dx = -3;
	#while (dx <= 3)

		#declare dy = -3;
		#while (dy <= 3)
	
			#declare dz = -3;
			#while (dz <= 3)

				object
				{
					MetalBox
					rotate x*cuberot
					translate <dx * cubesep, dy * cubesep + totaloffs, dz * cubesep>
				}
			
				#declare dz = dz + 1;
			#end
		
			#declare dy = dy + 1;
		#end

		#declare dx = dx + 1;
	#end
	
	rotate y*totalrot
}
